@@ -18,25 +18,6 @@
  */
 package org.apache.maven.plugins.invoker;
 
-/*
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- *
- *   http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.
- */
-
 import java.io.File;
 import java.io.FileNotFoundException;
 import java.io.IOException;
@@ -48,6 +29,7 @@ import java.util.Arrays;
 import java.util.Collection;
 import java.util.Iterator;
 import java.util.List;
+import java.util.Objects;
 import java.util.Properties;
 import java.util.stream.Collectors;
 
@@ -56,7 +38,6 @@ import org.apache.maven.project.MavenProject;
 import org.apache.maven.toolchain.MisconfiguredToolchainException;
 import org.apache.maven.toolchain.ToolchainPrivate;
 import org.codehaus.plexus.util.Os;
-import org.codehaus.plexus.util.StringUtils;
 
 /**
  * Provides utility methods for selecting build jobs based on environmental conditions.
@@ -66,7 +47,11 @@ import org.codehaus.plexus.util.StringUtils;
 class SelectorUtils {
 
     static void parseList(String list, Collection<String> includes, Collection<String> excludes) {
-        String[] tokens = (list != null) ? StringUtils.split(list, ",") : new String[0];
+        if (Objects.isNull(list)) {
+            return;
+        }
+
+        String[] tokens = list.split(",+");
 
         for (String token1 : tokens) {
             String token = token1.trim();
@@ -88,17 +73,10 @@ class SelectorUtils {
     }
 
     static boolean isOsFamily(List<String> families, boolean defaultMatch) {
-        if (families != null && !families.isEmpty()) {
-            for (String family : families) {
-                if (Os.isFamily(family)) {
-                    return true;
-                }
-            }
-
-            return false;
-        } else {
+        if (families == null || families.isEmpty()) {
             return defaultMatch;
         }
+        return families.stream().anyMatch(Os::isFamily);
     }
 
     /**
@@ -118,7 +96,8 @@ class SelectorUtils {
                     .getClassLoader()
                     .getResourceAsStream("META-INF/maven/org.apache.maven/maven-core/pom.properties"));
             // CHECKSTYLE_ON: LineLength
-            return StringUtils.trim(properties.getProperty("version"));
+            String str = properties.getProperty("version");
+            return str == null ? null : str.trim();
         } catch (Exception e) {
             return null;
         }
@@ -140,7 +119,8 @@ class SelectorUtils {
                 try (InputStream in = url.openStream()) {
                     Properties properties = new Properties();
                     properties.load(in);
-                    String version = StringUtils.trim(properties.getProperty("version"));
+                    String str = properties.getProperty("version");
+                    String version = str == null ? null : str.trim();
                     if (version != null) {
                         return version;
                     }
@@ -152,10 +132,6 @@ class SelectorUtils {
         return null;
     }
 
-    static boolean isMavenVersion(String mavenSpec) {
-        return isMavenVersion(mavenSpec, getMavenVersion());
-    }
-
     static boolean isMavenVersion(String mavenSpec, String actualVersion) {
         List<String> includes = new ArrayList<>();
         List<String> excludes = new ArrayList<>();
@@ -170,15 +146,6 @@ class SelectorUtils {
         return System.getProperty("java.version", "");
     }
 
-    static String getJreVersion(File javaHome) {
-        // @todo detect actual version
-        return null;
-    }
-
-    static boolean isJreVersion(String jreSpec) {
-        return isJreVersion(jreSpec, getJreVersion());
-    }
-
     static boolean isJreVersion(String jreSpec, String actualJreVersion) {
         List<String> includes = new ArrayList<>();
         List<String> excludes = new ArrayList<>();
@@ -189,44 +156,39 @@ class SelectorUtils {
         return isJreVersion(jreVersion, includes, true) && !isJreVersion(jreVersion, excludes, false);
     }
 
-    static boolean isJreVersion(List<Integer> jreVersion, List<String> versionPatterns, boolean defaultMatch) {
-        if (versionPatterns != null && !versionPatterns.isEmpty()) {
-            for (String versionPattern : versionPatterns) {
-                if (isJreVersion(jreVersion, versionPattern)) {
-                    return true;
-                }
-            }
-
-            return false;
-        } else {
+    static boolean isJreVersion(List<Integer> jreVersions, List<String> versionPatterns, boolean defaultMatch) {
+        if (versionPatterns == null || versionPatterns.isEmpty()) {
             return defaultMatch;
         }
+
+        return versionPatterns.stream().anyMatch(versionPattern -> isJreVersion(jreVersions, versionPattern));
     }
 
-    static boolean isJreVersion(List<Integer> jreVersion, String versionPattern) {
+    static boolean isJreVersion(List<Integer> jreVersions, String versionPattern) {
         List<Integer> checkVersion = parseVersion(versionPattern);
 
         if (versionPattern.endsWith("+")) {
             // 1.5+ <=> [1.5,)
-            return compareVersions(jreVersion, checkVersion) >= 0;
+            return compareVersions(jreVersions, checkVersion) >= 0;
         } else if (versionPattern.endsWith("-")) {
             // 1.5- <=> (,1.5)
-            return compareVersions(jreVersion, checkVersion) < 0;
+            return compareVersions(jreVersions, checkVersion) < 0;
         } else {
             // 1.5 <=> [1.5,1.6)
-            return checkVersion.size() <= jreVersion.size()
-                    && checkVersion.equals(jreVersion.subList(0, checkVersion.size()));
+            return checkVersion.size() <= jreVersions.size()
+                    && checkVersion.equals(jreVersions.subList(0, checkVersion.size()));
         }
     }
 
     static List<Integer> parseVersion(String version) {
-        version = version.replaceAll("[^0-9]", ".");
+        version = version.replaceAll("\\D", ".");
 
-        String[] tokens = StringUtils.split(version, ".");
+        String[] tokens = version.split("\\s*\\.+\\s*");
 
-        List<Integer> numbers = Arrays.stream(tokens).map(Integer::valueOf).collect(Collectors.toList());
-
-        return numbers;
+        return Arrays.stream(tokens)
+                .filter(s -> !s.isEmpty())
+                .map(Integer::valueOf)
+                .collect(Collectors.toList());
     }
 
     static int compareVersions(List<Integer> version1, List<Integer> version2) {
